@@ -1,10 +1,3 @@
-#include "boolean_network.h"
-#include "helper_functions.h"
-#include <R.h>
-#include <Rinternals.h>
-#include <stdbool.h>
-#include <stdlib.h>
-
 /*
  * This code is derived from the BoolNet package.
  * Original files: BoolNet/src/statespace_search.h,
@@ -12,6 +5,13 @@
  *                 BoolNet/src/attractor_search_interface.c
  */
 
+#include "boolean_network.h"
+#include "helper_functions.h"
+#include <R.h>
+#include <Rinternals.h>
+#include <stdbool.h>
+#include <stdlib.h>
+
 static inline void apply_single_function_PEW(unsigned int *currentState,
                                              unsigned int geneIdx,
                                              ProbabilisticEdgeWeight *net) {
@@ -133,9 +133,12 @@ void state_transition_PEW_synchronous(unsigned int *currentState,
         // if the input of the function is not 0 (constant gene), take input bit
         {
           gene = net->inputs[k] - 1;
-          bit = (GET_BIT(
-              currentState[net->non_fixed_node_bits[gene] / BITS_PER_BLOCK_32],
-              net->non_fixed_node_bits[gene] % BITS_PER_BLOCK_32));
+          bit = (GET_BIT(currentState[gene / BITS_PER_BLOCK_32],
+                         gene % BITS_PER_BLOCK_32));
+
+          // bit = (GET_BIT(currentState[net->non_fixed_node_bits[gene] / BITS_PER_BLOCK_32],
+          //                net->non_fixed_node_bits[gene] % BITS_PER_BLOCK_32));
+
 
           if (bit == 0) {
             if (doublerand_1() > net->p_off[gene]) // net->p_off[gene]
@@ -715,7 +718,7 @@ SEXP get_node_activities_PEW_async_R(SEXP inputs, SEXP input_positions,
   network.outputs = INTEGER(outputs);
   network.output_positions = INTEGER(output_positions);
   network.fixed_nodes = INTEGER(fixed_nodes);
-  network.non_fixed_node_bits = CALLOC(network.num_nodes, sizeof(unsigned int));
+  //network.non_fixed_node_bits = CALLOC(network.num_nodes, sizeof(unsigned int));
   network.p_on = REAL(p_on);
   network.p_off = REAL(p_off);
 
@@ -727,12 +730,12 @@ SEXP get_node_activities_PEW_async_R(SEXP inputs, SEXP input_positions,
   if ((!isNull(initial_prob)) && (length(initial_prob) > 0))
     _initial_prob = REAL(initial_prob);
 
-  unsigned int num_non_fixed = 0, i;
-  for (i = 0; i < network.num_nodes; i++) {
-    if (network.fixed_nodes[i] == -1) {
-      network.non_fixed_node_bits[i] = num_non_fixed++;
-    }
-  }
+  // unsigned int num_non_fixed = 0, i;
+  // for (i = 0; i < network.num_nodes; i++) {
+  //   if (network.fixed_nodes[i] == -1) {
+  //     network.non_fixed_node_bits[i] = num_non_fixed++;
+  //   }
+  // }
 
   unsigned int _num_elements;
 
@@ -786,7 +789,7 @@ SEXP get_node_activities_PEW_async_R(SEXP inputs, SEXP input_positions,
 
   UNPROTECT(1);
 
-  FREE(network.non_fixed_node_bits);
+  //FREE(network.non_fixed_node_bits);
 
   return result;
 }
@@ -804,7 +807,7 @@ SEXP get_node_activities_PEW_sync_R(SEXP inputs, SEXP input_positions,
   network.outputs = INTEGER(outputs);
   network.output_positions = INTEGER(output_positions);
   network.fixed_nodes = INTEGER(fixed_nodes);
-  network.non_fixed_node_bits = CALLOC(network.num_nodes, sizeof(unsigned int));
+  //network.non_fixed_node_bits = CALLOC(network.num_nodes, sizeof(unsigned int));
   network.p_on = REAL(p_on);
   network.p_off = REAL(p_off);
 
@@ -812,12 +815,12 @@ SEXP get_node_activities_PEW_sync_R(SEXP inputs, SEXP input_positions,
   if ((!isNull(initial_prob)) && (length(initial_prob) > 0))
     _initial_prob = REAL(initial_prob);
 
-  unsigned int num_non_fixed = 0, i;
-  for (i = 0; i < network.num_nodes; i++) {
-    if (network.fixed_nodes[i] == -1) {
-      network.non_fixed_node_bits[i] = num_non_fixed++;
-    }
-  }
+  // unsigned int num_non_fixed = 0, i;
+  // for (i = 0; i < network.num_nodes; i++) {
+  //   if (network.fixed_nodes[i] == -1) {
+  //     network.non_fixed_node_bits[i] = num_non_fixed++;
+  //   }
+  // }
 
   unsigned int _num_elements;
 
@@ -866,7 +869,7 @@ SEXP get_node_activities_PEW_sync_R(SEXP inputs, SEXP input_positions,
 
   UNPROTECT(1);
 
-  FREE(network.non_fixed_node_bits);
+  //FREE(network.non_fixed_node_bits);
 
   return result;
 }
@@ -885,7 +888,7 @@ SEXP get_pairwise_transitions_PEW_async_R(SEXP inputs, SEXP input_positions,
   network.outputs = INTEGER(outputs);
   network.output_positions = INTEGER(output_positions);
   network.fixed_nodes = INTEGER(fixed_nodes);
-  network.non_fixed_node_bits = CALLOC(network.num_nodes, sizeof(unsigned int));
+  //network.non_fixed_node_bits = CALLOC(network.num_nodes, sizeof(unsigned int));
   network.p_on = REAL(p_on);
   network.p_off = REAL(p_off);
 
@@ -893,14 +896,14 @@ SEXP get_pairwise_transitions_PEW_async_R(SEXP inputs, SEXP input_positions,
   if ((!isNull(update_prob)) && (length(update_prob) > 0))
     _update_prob = REAL(update_prob);
 
-  unsigned int num_non_fixed = 0, i;
-  for (i = 0; i < network.num_nodes; i++) {
-    if (network.fixed_nodes[i] == -1) {
-      network.non_fixed_node_bits[i] = num_non_fixed++;
-    }
-  }
+  // unsigned int num_non_fixed = 0, i;
+  // for (i = 0; i < network.num_nodes; i++) {
+  //   if (network.fixed_nodes[i] == -1) {
+  //     network.non_fixed_node_bits[i] = num_non_fixed++;
+  //   }
+  // }
 
-  unsigned int j = 0;
+  unsigned int i, j = 0;
 
   unsigned int _num_elements;
 
@@ -947,7 +950,7 @@ SEXP get_pairwise_transitions_PEW_async_R(SEXP inputs, SEXP input_positions,
 
   UNPROTECT(1);
 
-  FREE(network.non_fixed_node_bits);
+  //FREE(network.non_fixed_node_bits);
   FREE(transition_matrix);
   FREE(_states_2d);
 
@@ -968,18 +971,18 @@ SEXP get_pairwise_transitions_PEW_sync_R(SEXP inputs, SEXP input_positions,
   network.outputs = INTEGER(outputs);
   network.output_positions = INTEGER(output_positions);
   network.fixed_nodes = INTEGER(fixed_nodes);
-  network.non_fixed_node_bits = CALLOC(network.num_nodes, sizeof(unsigned int));
+  //network.non_fixed_node_bits = CALLOC(network.num_nodes, sizeof(unsigned int));
   network.p_on = REAL(p_on);
   network.p_off = REAL(p_off);
 
-  unsigned int num_non_fixed = 0, i;
-  for (i = 0; i < network.num_nodes; i++) {
-    if (network.fixed_nodes[i] == -1) {
-      network.non_fixed_node_bits[i] = num_non_fixed++;
-    }
-  }
+  // unsigned int num_non_fixed = 0, i;
+  // for (i = 0; i < network.num_nodes; i++) {
+  //   if (network.fixed_nodes[i] == -1) {
+  //     network.non_fixed_node_bits[i] = num_non_fixed++;
+  //   }
+  // }
 
-  unsigned int j = 0;
+  unsigned int i, j = 0;
 
   unsigned int _num_elements;
 
@@ -1026,7 +1029,7 @@ SEXP get_pairwise_transitions_PEW_sync_R(SEXP inputs, SEXP input_positions,
 
   UNPROTECT(1);
 
-  FREE(network.non_fixed_node_bits);
+  //FREE(network.non_fixed_node_bits);
   FREE(transition_matrix);
   FREE(_states_2d);
 
@@ -1049,7 +1052,7 @@ SEXP get_reached_states_PEW_async_batch_R(SEXP inputs, SEXP input_positions,
   network.outputs = INTEGER(outputs);
   network.output_positions = INTEGER(output_positions);
   network.fixed_nodes = INTEGER(fixed_nodes);
-  network.non_fixed_node_bits = CALLOC(network.num_nodes, sizeof(unsigned int));
+  //network.non_fixed_node_bits = CALLOC(network.num_nodes, sizeof(unsigned int));
   network.p_on = REAL(p_on);
   network.p_off = REAL(p_off);
 
@@ -1070,12 +1073,12 @@ SEXP get_reached_states_PEW_async_batch_R(SEXP inputs, SEXP input_positions,
   else
     _num_elements = network.num_nodes / BITS_PER_BLOCK_32 + 1;
 
-  unsigned int num_non_fixed = 0, i;
-  for (i = 0; i < network.num_nodes; i++) {
-    if (network.fixed_nodes[i] == -1) {
-      network.non_fixed_node_bits[i] = num_non_fixed++;
-    }
-  }
+  // unsigned int num_non_fixed = 0, i;
+  // for (i = 0; i < network.num_nodes; i++) {
+  //   if (network.fixed_nodes[i] == -1) {
+  //     network.non_fixed_node_bits[i] = num_non_fixed++;
+  //   }
+  // }
 
   int _num_steps = *INTEGER(steps);
 
@@ -1099,7 +1102,7 @@ SEXP get_reached_states_PEW_async_batch_R(SEXP inputs, SEXP input_positions,
 
   UNPROTECT(1);
 
-  FREE(network.non_fixed_node_bits);
+  //FREE(network.non_fixed_node_bits);
   FREE(reached_states);
 
   return result;
@@ -1118,7 +1121,7 @@ SEXP get_reached_states_PEW_sync_batch_R(SEXP inputs, SEXP input_positions,
   network.outputs = INTEGER(outputs);
   network.output_positions = INTEGER(output_positions);
   network.fixed_nodes = INTEGER(fixed_nodes);
-  network.non_fixed_node_bits = CALLOC(network.num_nodes, sizeof(unsigned int));
+  //network.non_fixed_node_bits = CALLOC(network.num_nodes, sizeof(unsigned int));
   network.p_on = REAL(p_on);
   network.p_off = REAL(p_off);
 
@@ -1135,12 +1138,12 @@ SEXP get_reached_states_PEW_sync_batch_R(SEXP inputs, SEXP input_positions,
   else
     _num_elements = network.num_nodes / BITS_PER_BLOCK_32 + 1;
 
-  unsigned int num_non_fixed = 0, i;
-  for (i = 0; i < network.num_nodes; i++) {
-    if (network.fixed_nodes[i] == -1) {
-      network.non_fixed_node_bits[i] = num_non_fixed++;
-    }
-  }
+  // unsigned int num_non_fixed = 0, i;
+  // for (i = 0; i < network.num_nodes; i++) {
+  //   if (network.fixed_nodes[i] == -1) {
+  //     network.non_fixed_node_bits[i] = num_non_fixed++;
+  //   }
+  // }
 
   int _num_steps = *INTEGER(steps);
 
@@ -1161,7 +1164,7 @@ SEXP get_reached_states_PEW_sync_batch_R(SEXP inputs, SEXP input_positions,
 
   UNPROTECT(1);
 
-  FREE(network.non_fixed_node_bits);
+  //FREE(network.non_fixed_node_bits);
   FREE(reached_states);
 
   return result;
@@ -1181,7 +1184,7 @@ SEXP get_reached_states_PEW_async_single_R(SEXP inputs, SEXP input_positions,
   network.outputs = INTEGER(outputs);
   network.output_positions = INTEGER(output_positions);
   network.fixed_nodes = INTEGER(fixed_nodes);
-  network.non_fixed_node_bits = CALLOC(network.num_nodes, sizeof(unsigned int));
+  //network.non_fixed_node_bits = CALLOC(network.num_nodes, sizeof(unsigned int));
   network.p_on = REAL(p_on);
   network.p_off = REAL(p_off);
 
@@ -1189,12 +1192,12 @@ SEXP get_reached_states_PEW_async_single_R(SEXP inputs, SEXP input_positions,
   if ((!isNull(update_prob)) && (length(update_prob) > 0))
     _update_prob = REAL(update_prob);
 
-  unsigned int num_non_fixed = 0, i;
-  for (i = 0; i < network.num_nodes; i++) {
-    if (network.fixed_nodes[i] == -1) {
-      network.non_fixed_node_bits[i] = num_non_fixed++;
-    }
-  }
+  // unsigned int num_non_fixed = 0, i;
+  // for (i = 0; i < network.num_nodes; i++) {
+  //   if (network.fixed_nodes[i] == -1) {
+  //     network.non_fixed_node_bits[i] = num_non_fixed++;
+  //   }
+  // }
 
   unsigned int *_initial_state = NULL;
   if ((!isNull(initial_state)) && (length(initial_state) > 0))
@@ -1230,7 +1233,7 @@ SEXP get_reached_states_PEW_async_single_R(SEXP inputs, SEXP input_positions,
 
   UNPROTECT(1);
 
-  FREE(network.non_fixed_node_bits);
+  //FREE(network.non_fixed_node_bits);
   FREE(reached_states);
 
   return result;
@@ -1249,16 +1252,16 @@ SEXP get_reached_states_PEW_sync_single_R(SEXP inputs, SEXP input_positions,
   network.outputs = INTEGER(outputs);
   network.output_positions = INTEGER(output_positions);
   network.fixed_nodes = INTEGER(fixed_nodes);
-  network.non_fixed_node_bits = CALLOC(network.num_nodes, sizeof(unsigned int));
+  //network.non_fixed_node_bits = CALLOC(network.num_nodes, sizeof(unsigned int));
   network.p_on = REAL(p_on);
   network.p_off = REAL(p_off);
 
-  unsigned int num_non_fixed = 0, i;
-  for (i = 0; i < network.num_nodes; i++) {
-    if (network.fixed_nodes[i] == -1) {
-      network.non_fixed_node_bits[i] = num_non_fixed++;
-    }
-  }
+  // unsigned int num_non_fixed = 0, i;
+  // for (i = 0; i < network.num_nodes; i++) {
+  //   if (network.fixed_nodes[i] == -1) {
+  //     network.non_fixed_node_bits[i] = num_non_fixed++;
+  //   }
+  // }
 
   unsigned int *_initial_state = NULL;
   if ((!isNull(initial_state)) && (length(initial_state) > 0))
@@ -1292,7 +1295,7 @@ SEXP get_reached_states_PEW_sync_single_R(SEXP inputs, SEXP input_positions,
 
   UNPROTECT(1);
 
-  FREE(network.non_fixed_node_bits);
+  //FREE(network.non_fixed_node_bits);
   FREE(reached_states);
 
   return result;
